@@ -157,7 +157,15 @@ for (i in 2:(k-1)){ # loop on date
                 } else {
                   dffish = (sum(!zeros_rows)-1)*(sum(!zeros_cols)-1)
                 }
-				        stafish = stats::qchisq(1-pvalfish, dffish)
+				        #stafish = stats::qchisq(1-pvalfish, dffish)
+				        if (is.finite(pvalfish) && dffish > 0) {
+				          stafish <- stats::qchisq(1 - pvalfish, dffish)
+				        } else {
+				          # degenerate case: no information in the table
+				          stafish  <- 0
+				          dffish   <- 0
+				          pvalfish <- 1
+				        }
                 table_multi_3sm[where_in_table_3sm,1] = i
                 table_multi_3sm[where_in_table_3sm,2] = l
                 table_multi_3sm[where_in_table_3sm,3] = stafish
@@ -204,7 +212,15 @@ for (i in 2:(k-1)){ # loop on date
                 } else {
                   dffish = (sum(!zeros_rows)-1)*(sum(!zeros_cols)-1)
                 }
-                stafish = stats::qchisq(1-pvalfish, dffish)
+                #stafish = stats::qchisq(1-pvalfish, dffish)
+                if (is.finite(pvalfish) && dffish > 0) {
+                  stafish <- stats::qchisq(1 - pvalfish, dffish)
+                } else {
+                  # degenerate case: no information in the table
+                  stafish  <- 0
+                  dffish   <- 0
+                  pvalfish <- 1
+                }
                 table_multi_3sm[where_in_table_3sm,1] = i
                 table_multi_3sm[where_in_table_3sm,2] = l
                 table_multi_3sm[where_in_table_3sm,3] = stafish + table_multi_3sm[where_in_table_3sm,3]
@@ -258,7 +274,15 @@ for (i in 2:(k-1)){ # loop on date
                 } else {
                   dffish = (sum(!zeros_rows)-1)*(sum(!zeros_cols)-1)
                 }
-    		        stafish = stats::qchisq(1-pvalfish, dffish)
+    		        #stafish = stats::qchisq(1-pvalfish, dffish)
+    		        if (is.finite(pvalfish) && dffish > 0) {
+    		          stafish <- stats::qchisq(1 - pvalfish, dffish)
+    		        } else {
+    		          # degenerate case: no information in the table
+    		          stafish  <- 0
+    		          dffish   <- 0
+    		          pvalfish <- 1
+    		        }
                 table_multi_3sm[where_in_table_3sm,1] = i
                 table_multi_3sm[where_in_table_3sm,2] = l
                 table_multi_3sm[where_in_table_3sm,3] = stafish + table_multi_3sm[where_in_table_3sm,3]
